@@ -1,3 +1,3 @@
-from .dynamodb import DynamoDBStore
+from .edge import EdgeStore
 from .memory import MemoryStore
 from .file import FileStore
\ No newline at end of file
